<?php
/**
 * @file
 * Guestbook module theme alter by the whisper module.
 */
function whisper_guestbook_entry($uid, $entry, $comment_entry = NULL, $zebra, $confirm_delete = FALSE) {
  global $user;
  $output = '';
  $display = (array) variable_get('guestbook_display', array('date', 'email', 'website', 'comments'));

  $output .= "\n<div class=\"comment guestbook-entry $zebra\">\n";
  if ($comment_entry == $entry['id']) {
    $output .= '<a name="comment-entry"></a>';
  }

  // author
  if ($entry['author'] == 0) {
    $author = "<b>". check_plain($entry['anonname']) ."</b>";
  }
  else {
    $author = theme('guestbook_user_picture', $entry['author']);
  }

  /******************************************************************/
  // Do not show sealed entry if not allowed, $uid is same as $entry['recipient']
  if ($entry['sealed'] && !(_guestbook_access('administer', $entry['author']) || _guestbook_access('administer', $uid))) {
    $entry['message'] = t('Sealed');
    if (!empty($entry['comment'])) {
      $entry['comment'] = $entry['message'];
    }
  }
  // Allow authors to edit seal status
  $option = '';
  if ((_guestbook_access('administer', $entry['author']) || _guestbook_access('administer', $uid)) && !strpos(request_uri(), 'delete')) {
    drupal_add_css(drupal_get_path('module', 'whisper') .'/whisper.css');
	$option = drupal_get_form('guestbook_seal_form', $entry);
  }
  /******************************************************************/

  $output .= $option .'<div class="author">'. $author .'</div>';

  // date, email, website
  $output .= '<div class="submitted">';
  if (in_array('date', $display)) {
    $output .= format_date($entry['created'], 'medium');
  }

  /******************************************************************/
  // Always show sealed icon
  if ($entry['sealed']) {
    $output .= ' <img src="'. base_path() . drupal_get_path('module', 'whisper') .'/images/lock.gif" alt="'. t('Sealed') .'" title="'. t('Sealed') .'" />';
  }
  /******************************************************************/

  if (in_array('email', $display) && !empty($entry['anonemail'])) {
    $output .= '&nbsp;|&nbsp;<a href="mailto:'. check_url($entry['anonemail']) .'">'. t('E-mail') .'</a>';
  }
  if (in_array('website', $display) && !empty($entry['anonwebsite'])) {
    // Auto-prepend HTTP protocol if website contains no protocol.
    if (strpos($entry['anonwebsite'], '://') === FALSE) {
      $entry['anonwebsite'] = 'http://'. $entry['anonwebsite'];
    }
    $output .= '&nbsp;|&nbsp;<a href="'. check_url($entry['anonwebsite']) .'">'. t('Website') .'</a>&nbsp;';
  }
  $output .= '</div>';

  // message
  $output .= '<div class="content guestbook-message">'. check_markup($entry['message'], variable_get('guestbook_input_format', 1, FALSE)) .'</div>';

  if ($entry['picture']) {
    $output .= '<div style="clear:both;"></div>';
  }

  // comment
  $output .= theme('guestbook_entry_comment', $uid, $entry, $comment_entry);

  // links
  if (_guestbook_access('administer', $uid) && !$confirm_delete) {
    if ($comment_entry != $entry['id']) {
      $pager = !empty($_GET['page']) ? 'page='. $_GET['page'] : NULL;
      $output .= '<div class="links">&raquo; ';
      $output .= l(t('Delete entry'), guestbook_path($uid) .'/delete/'. $entry['id'], array('query' => $pager)) .'&nbsp;|&nbsp;';
      $output .= l($entry['comment'] == '' ? t('Add comment') : t('Edit comment'), guestbook_path($uid) .'/comment/'. $entry['id'], array('query' => $pager, 'fragment' => 'comment-entry'));
      $output .= '</div>';
    }
  }

  $output .= "\n</div><div style=\"clear:both;\"></div>";
  return $output;
}

function guestbook_seal_form($context, $entry) {  
  $form['submit'] = array(
    '#type' => 'submit',
    '#name' => $entry['id'],
    '#value' => $entry['sealed'] ? t('Unseal entry') : t('Seal entry'),
  );
  
  unset($sealed); // Destroy variable
  return $form;
}

/**
 * Form submission handler, which functions like a hook.
 * Note that the params $form and &$form_state are new in D6. They
 * replace $form_id and $form_values.
 */
function guestbook_seal_form_submit($form, &$form_state) {
  db_query("UPDATE {guestbook} "
      ."SET sealed = IF (sealed = 1,0,1) "
      ."WHERE id = %d",
    array_shift(array_keys($form_state['clicked_button']['#post']))
  );
}